import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)

# 同花顺概念
SELF_CHOOSE_THS_CONCEPT = 'ths_concept'
# 同花顺行业
SELF_CHOOSE_THS_INDUSTRY = 'ths_industry'

SELF_CHOOSE_KPL_CONCEPT = 'kpl_concept'

# 开盘啦一级概念
SELF_CHOOSE_KPL_FIRST_CONCEPT = 'kpl_first_concept'

# 开盘啦二级概念
SELF_CHOOSE_KPL_SECOND_CONCEPT = 'kpl_second_concept'





import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 14
project_path = file_path[0:end]
sys.path.append(project_path)

import requests

"""
东方财富网 数据接口 获取单个股票行情数据
http://quote.eastmoney.com/sz002497.html
"""

import pandas as pd
from loguru import logger
import json


def all_stock_ticker_data_new(fields, fs) -> pd.DataFrame:
    url = "https://13.push2.eastmoney.com/api/qt/clist/get"
    # url = "https://push2.eastmoney.com/api/qt/clist/get?cb=jQuery112303212778189608789_1645434416300&fid=f62&po=1&pz=6000&pn=1&np=1&fltt=2&invt=2&ut=b2884a393a59ad64002292a3e90d46a5&fs=m%3A0%2Bt%3A6%2Bf%3A!2%2Cm%3A0%2Bt%3A13%2Bf%3A!2%2Cm%3A0%2Bt%3A80%2Bf%3A!2%2Cm%3A1%2Bt%3A2%2Bf%3A!2%2Cm%3A1%2Bt%3A23%2Bf%3A!2%2Cm%3A0%2Bt%3A7%2Bf%3A!2%2Cm%3A1%2Bt%3A3%2Bf%3A!2&fields=f12%2Cf14%2Cf2%2Cf3%2Cf62%2Cf184%2Cf66%2Cf69%2Cf72%2Cf75%2Cf78%2Cf81%2Cf84%2Cf87%2Cf204%2Cf205%2Cf124%2Cf1%2Cf13"
    params = {
        "cb": "jQuery1124046660442520420653_1660036672477",
        "pn": "1",
        "pz": "10000",
        "po": "1",
        "np": "1",
        "ut": " bd1d9ddb04089700cf9c27f6f7426281",
        "fltt": "2",
        "invt": "2",
        "wbp2u": "|0|0|0|web",
        "fid": "f3",
        "fs": fs,
        "fields": fields,
        "_": 1660036672518
    }
    try:
        r = requests.get(url, params)
        data_text = r.text
        begin_index = data_text.index('[')
        end_index = data_text.index(']')
        data_json = data_text[begin_index:end_index + 1]
        data_json = json.loads(data_json)
        if data_json is None:
            return pd.DataFrame()
        return pd.DataFrame(data_json)
    except Exception as e:
        logger.error("获取股票列表,实时行情异常:{}", e)
        return None


# f212 卖1
# f211 买1
# f31 买1价格
# "f32" : 卖1价格


# 获取所有股票实时行情数据    f33,委比
def get_real_time_quotes_all_stocks():
    # todo old version
    # stock_ticker_data = all_stock_ticker_data(
    #     "f352,f2,f3,f5,f6,f8,f10,f11,f12,f14,f15,f16,f17,f18,f20,f21,f26,"
    #     "f33,f34,f35,f62,f66,f69,f72,f100,f184",
    #     "m:0+t:6+f:!2,m:0+t:13+f:!2,m:0+t:80+f:!2,m:1+t:2+f:!2,m:1+t:23+f:!2,m:0+t:7+f:!2,m:1+t:3+f:!2")

    # todo new version
    stock_ticker_data = all_stock_ticker_data_new(
        "f352,f2,f3,f5,f6,f8,f10,f11,f22,f12,f14,f15,f16,f17,f18,f20,f21,f26,"
        "f33,f34,f35,f62,f66,f69,f72,f100,f184,f211,f212",
        "m:0 t:6,m:0 t:80,m:1 t:2,m:1 t:23,m:0 t:81 s:2048")

    temp_df = stock_ticker_data.rename(columns={
        "f2": "now_price",
        "f3": "chg",
        "f5": "volume",
        "f6": "amount",
        "f8": "exchange",
        "f10": "quantity_ratio",
        "f22": "up_speed",
        "f11": "up_speed_05",
        "f12": "symbol",
        "f14": "name",
        "f15": "high",
        "f16": "low",
        "f17": "open",
        "f18": "yesterday_price",
        "f20": "total_mv",
        "f21": "flow_mv",
        "f26": "list_date",
        "f33": "wei_bi",
        "f34": "outer_disk",
        "f35": "inner_disk",
        "f62": "today_main_net_inflow",
        "f66": "super_large_order_net_inflow",
        "f69": "super_large_order_net_inflow_ratio",
        "f72": "large_order_net_inflow",
        # "f78": "medium_order_net_inflow",
        # "f84": "small_order_net_inflow",
        "f100": "industry",
        # "f103": "concept",
        "f184": "today_main_net_inflow_ratio",
        "f352": "average_price",
        "f211": "buy_1_num",
        "f212": "sell_1_num"
    })
    temp_df.loc[temp_df['buy_1_num'] == '-', 'buy_1_num'] = 0
    temp_df.loc[temp_df['sell_1_num'] == '-', 'sell_1_num'] = 0
    temp_df.loc[temp_df['up_speed_05'] == '-', 'up_speed_05'] = 0
    temp_df.loc[temp_df['up_speed'] == '-', 'up_speed'] = 0
    temp_df.loc[temp_df['average_price'] == '-', 'average_price'] = 0
    temp_df.loc[temp_df['wei_bi'] == '-', 'wei_bi'] = 0
    temp_df.loc[temp_df['yesterday_price'] == '-', 'yesterday_price'] = 0
    temp_df.loc[temp_df['now_price'] == '-', 'now_price'] = 0
    temp_df.loc[temp_df['chg'] == '-', 'chg'] = 0
    temp_df.loc[temp_df['volume'] == '-', 'volume'] = 0
    temp_df.loc[temp_df['amount'] == '-', 'amount'] = 0
    temp_df.loc[temp_df['exchange'] == '-', 'exchange'] = 0
    temp_df.loc[temp_df['quantity_ratio'] == '-', 'quantity_ratio'] = 0
    temp_df.loc[temp_df['high'] == '-', 'high'] = 0
    temp_df.loc[temp_df['low'] == '-', 'low'] = 0
    temp_df.loc[temp_df['open'] == '-', 'open'] = 0
    temp_df.loc[temp_df['total_mv'] == '-', 'total_mv'] = 0
    temp_df.loc[temp_df['flow_mv'] == '-', 'flow_mv'] = 0
    temp_df.loc[temp_df['inner_disk'] == '-', 'inner_disk'] = 0
    temp_df.loc[temp_df['outer_disk'] == '-', 'outer_disk'] = 0
    temp_df.loc[temp_df['today_main_net_inflow_ratio'] == '-', 'today_main_net_inflow_ratio'] = 0
    temp_df.loc[temp_df['today_main_net_inflow'] == '-', 'today_main_net_inflow'] = 0
    temp_df.loc[temp_df['super_large_order_net_inflow'] == '-', 'super_large_order_net_inflow'] = 0
    temp_df.loc[temp_df['super_large_order_net_inflow_ratio'] == '-', 'super_large_order_net_inflow_ratio'] = 0
    temp_df.loc[temp_df['large_order_net_inflow'] == '-', 'large_order_net_inflow'] = 0
    # temp_df.loc[temp_df['medium_order_net_inflow'] == '-', 'medium_order_net_inflow'] = 0
    # temp_df.loc[temp_df['small_order_net_inflow'] == '-', 'small_order_net_inflow'] = 0

    temp_df["list_date"] = pd.to_numeric(temp_df["list_date"], errors="coerce")
    temp_df["wei_bi"] = pd.to_numeric(temp_df["wei_bi"], errors="coerce")
    temp_df["average_price"] = pd.to_numeric(temp_df["average_price"], errors="coerce")
    temp_df["yesterday_price"] = pd.to_numeric(temp_df["yesterday_price"], errors="coerce")
    temp_df["now_price"] = pd.to_numeric(temp_df["now_price"], errors="coerce")
    temp_df["chg"] = pd.to_numeric(temp_df["chg"], errors="coerce")
    temp_df["volume"] = pd.to_numeric(temp_df["volume"], errors="coerce")
    temp_df["amount"] = pd.to_numeric(temp_df["amount"], errors="coerce")
    temp_df["exchange"] = pd.to_numeric(temp_df["exchange"], errors="coerce")
    temp_df["quantity_ratio"] = pd.to_numeric(temp_df["quantity_ratio"], errors="coerce")
    temp_df["high"] = pd.to_numeric(temp_df["high"], errors="coerce")
    temp_df["low"] = pd.to_numeric(temp_df["low"], errors="coerce")
    temp_df["open"] = pd.to_numeric(temp_df["open"], errors="coerce")
    temp_df["total_mv"] = pd.to_numeric(temp_df["total_mv"], errors="coerce")
    temp_df["flow_mv"] = pd.to_numeric(temp_df["flow_mv"], errors="coerce")
    temp_df["outer_disk"] = pd.to_numeric(temp_df["outer_disk"], errors="coerce")
    temp_df["inner_disk"] = pd.to_numeric(temp_df["inner_disk"], errors="coerce")
    temp_df["today_main_net_inflow"] = pd.to_numeric(temp_df["today_main_net_inflow"], errors="coerce")
    temp_df["super_large_order_net_inflow"] = pd.to_numeric(temp_df["super_large_order_net_inflow"],
                                                            errors="coerce")
    temp_df["super_large_order_net_inflow_ratio"] = pd.to_numeric(temp_df["super_large_order_net_inflow_ratio"],
                                                                  errors="coerce")
    temp_df["large_order_net_inflow"] = pd.to_numeric(temp_df["large_order_net_inflow"],
                                                      errors="coerce")
    # temp_df["medium_order_net_inflow"] = pd.to_numeric(temp_df["medium_order_net_inflow"],
    #                                                    errors="coerce")
    # temp_df["small_order_net_inflow"] = pd.to_numeric(temp_df["small_order_net_inflow"], errors="coerce")

    # 大单比例
    temp_df['large_order_net_inflow_ratio'] = round((temp_df['large_order_net_inflow'] / temp_df['amount']) * 100, 2)

    # 外盘是内盘倍数
    temp_df['disk_ratio'] = round((temp_df['outer_disk'] - temp_df['inner_disk']) / temp_df['inner_disk'], 2)
    # 只有外盘没有内盘
    temp_df.loc[temp_df["inner_disk"] == 0, ['disk_ratio']] = 1688

    return temp_df


if __name__ == '__main__':
    df = get_real_time_quotes_all_stocks()
    df = df.loc[df['wei_bi'] == 100]
    print(df)



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 14
project_path = file_path[0:end]
sys.path.append(project_path)
from datetime import datetime, time
from datetime import timedelta
from functools import lru_cache
from mns_common.db.MongodbUtil import MongodbUtil

mongodb_util = MongodbUtil('27017')


@lru_cache(maxsize=None)
def is_trade_date(str_now_day):
    query_trade_date = {'_id': str_now_day}
    return mongodb_util.exist_data_query('trade_date_list', query_trade_date)


def is_afternoon_time(now_date):
    hour = now_date.hour
    return hour >= 13


def is_begin_one_hour(now_date):
    hour = now_date.hour
    minute = now_date.minute
    return ((hour == 9 and minute >= 30) or
            (hour == 10 and minute < 30))


def is_end_trade_ten_minute(now_date):
    hour = now_date.hour
    minute = now_date.minute
    weekday = now_date.isoweekday()
    no_trade_time = (hour >= 9 and minute >= 40) or weekday == 6 or weekday == 7
    return no_trade_time


def is_end_trade(now_date):
    hour = now_date.hour
    minute = now_date.minute
    weekday = now_date.isoweekday()
    no_trade_time = (hour >= 15 and minute >= 1) or weekday == 6 or weekday == 7
    return no_trade_time


def is_no_trade_time(now_date):
    hour = now_date.hour
    minute = now_date.minute
    weekday = now_date.isoweekday()
    no_trade_time = (
            (hour >= 15 and minute >= 0)
            or weekday == 6 or weekday == 7)
    return no_trade_time


def is_close_time(now_date):
    hour = now_date.hour
    weekday = now_date.isoweekday()
    no_trade_time = (hour >= 15) \
                    or weekday == 6 or weekday == 7
    return no_trade_time


# 是否是交易时间 9:26 同步一下数据 第25 分钟的内外盘数据还会变动
def is_trade_time(now_date):
    # return True
    hour = now_date.hour
    minute = now_date.minute
    second = now_date.second
    str_now_day = now_date.strftime('%Y-%m-%d')
    is_trade_day = is_trade_date(str_now_day)
    trade_time = (hour == 9 and minute == 25 and second > 20) \
                 or (hour == 9 and minute == 26 and second < 10) \
                 or (hour == 9 and minute >= 30) \
                 or (hour == 10) \
                 or (hour == 11 and minute <= 30) \
                 or (hour == 13) \
                 or (hour == 14 and minute < 57) \
                 or (hour == 15 and minute == 0 and second < 30)

    return is_trade_day and trade_time


# 是否是策略运行时间
def is_strategy_time(now_date):
    # return True
    hour = now_date.hour
    minute = now_date.minute
    second = now_date.second
    str_now_day = now_date.strftime('%Y-%m-%d')
    is_trade_day = is_trade_date(str_now_day)
    trade_time = (hour == 9 and minute == 25 and second > 10) \
                 or (hour == 9 and minute == 26 and second < 10) \
                 or (hour == 9 and minute >= 30) \
                 or (hour == 10) \
                 or (hour == 11 and minute < 30) \
                 or (hour == 13) \
                 or (hour == 14) \
                 or (hour == 15 and minute < 0)

    return is_trade_day and trade_time


# 是否是交易时间
def is_trade_time_save_data(now_date):
    hour = now_date.hour
    minute = now_date.minute
    weekday = now_date.isoweekday()
    str_now_day = now_date.strftime('%Y-%m-%d')
    is_trade_day = is_trade_date(str_now_day)
    no_trade_time = hour < 9 or (hour == 9 and minute < 30) or (
            hour == 11 and minute > 30) or hour == 12 or (hour >= 15 and minute >= 1) or weekday == 6 or weekday == 7

    first_sync = hour == 9 and minute == 26
    return (is_trade_day and bool(1 - no_trade_time)) or first_sync


# 是否是开盘时间 包含集合竞价
def is_open_time(now_date):
    hour = now_date.hour
    minute = now_date.minute
    weekday = now_date.isoweekday()
    str_now_day = now_date.strftime('%Y-%m-%d')
    is_trade_day = is_trade_date(str_now_day)
    no_trade_time = hour < 9 or (hour == 9 and 25 < minute < 30) or (hour == 9 and minute < 15) or \
                    (hour == 11 and minute > 30) or hour == 12 or hour >= 15 or weekday == 6 or weekday == 7
    return is_trade_day and bool(1 - no_trade_time)


def add_date(date_str, add_count=1):
    date = datetime.strptime(date_str, '%Y-%m-%d')
    new_date = date + timedelta(days=add_count)

    new_str_day = new_date.strftime('%Y-%m-%d')
    return new_str_day


def add_date_day(date_str, add_count=1):
    date = datetime.strptime(date_str, '%Y%m%d')
    new_date = date + timedelta(days=add_count)
    return new_date


def str_to_date(date_str, for_mart):
    date_time = datetime.strptime(date_str, for_mart)
    return date_time


def lash_date(date_str):
    date_time_begin = datetime.strptime(date_str, '%Y%m%d')
    date_str = date_time_begin.strftime('%Y-%m-%d')
    return date_str


# 已经交易的时间
def calculate_had_trade_minute(now_date):
    hour = now_date.hour
    minute = now_date.minute
    trade_minute = 1
    if hour == 9:
        if minute == 30:
            trade_minute = 1
        elif minute > 30:
            trade_minute = minute - 30
        else:
            trade_minute = 1
    elif hour == 10:
        trade_minute = minute + 30
    elif hour == 11:
        if minute <= 30:
            trade_minute = minute + 30 + 60
        elif minute > 30:
            trade_minute = 120
    elif hour == 12:
        trade_minute = 120
    elif hour == 13:
        trade_minute = minute + 30 + 30 + 60
    elif hour == 14:
        trade_minute = minute + 30 + 30 + 60 + 60
    elif hour < 9:
        trade_minute = 0
    elif hour >= 15:
        trade_minute = 60 + 60 + 60 + 60
    return trade_minute


def no_slash_date(date='-'):
    date = str(date)
    date = date.replace('-', '')
    return date


def calculate_mouth(date):
    return date.month


def calculate_year(date):
    return date.year


def last_day_of_week(date):
    return date.weekday() == 4


def last_day_month(date):
    month = date.month
    day = date.day
    if month in [1, 3, 5, 7, 8, 12] and day == 31:
        return True
    elif month in [4, 6, 9, 10, 11] and day == 30:
        return True
    elif run_nian(date) and month == 2 and day == 29:
        return True
    elif bool(1 - run_nian(date)) and month == 2 and day == 28:
        return True
    return False


def run_nian(date):
    year = date.year
    if (year % 4) == 0:
        if (year % 100) == 0:
            if (year % 400) == 0:
                return True
            else:
                return False
        else:
            return True
    else:
        return False


def days_diff(d1, d2):
    return (d1 - d2).days


def is_call_auction(str_now_date):
    now_date = str_to_date(str_now_date, "%Y-%m-%d %H:%M:%S")
    now_date_time = now_date.time()
    target_time_09_30 = time(9, 30)
    if now_date_time > target_time_09_30:
        return False
    else:
        return True


def is_new_concept_sync_time(now_date):
    # return True
    hour = now_date.hour
    if hour < 8 or hour > 15:
        return False
    return True


if __name__ == '__main__':
    is_call_auction("2023-07-05 09:29:01")



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)
import akshare as ak
import mns_common.utils.date_handle_util as date_handle_util
from loguru import logger
import mns_common.utils.data_frame_util as data_frame_util
from functools import lru_cache


def get_stock_tfp_by_day(str_day):
    stock_tfp_em_df = ak.stock_tfp_em(date_handle_util.no_slash_date(str_day))
    stock_tfp_em_df = stock_tfp_em_df.rename(
        columns={'序号': 'index',
                 '代码': 'symbol',
                 '名称': 'name',
                 '停牌时间': 'sus_begin_time',
                 '停牌截止时间': 'sus_end_time',
                 '停牌截止时间': 'sus_end_time',
                 '停牌期限': 'sus_period',
                 '停牌原因': 'sus_reason',
                 '所属市场': 'market',
                 '预计复牌时间': 'resume_time'
                 })
    return stock_tfp_em_df


# 获取停牌股票列表
@lru_cache(maxsize=None)
def get_stock_tfp_symbol_list_by_day(str_day):
    try:
        stock_tfp_em_df = get_stock_tfp_by_day(str_day)
        if data_frame_util.is_not_empty(stock_tfp_em_df):
            return list(stock_tfp_em_df['symbol'])
        else:
            return ['666666']

    except BaseException as e:
        logger.error("获取停牌信息异常:{}", e)
        return ['666666']



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)
from mns_common.db.MongodbUtil import MongodbUtil

mongodb_util = MongodbUtil('27017')

from functools import lru_cache


@lru_cache(maxsize=None)
def get_ths_cookie():
    stock_account_info = mongodb_util.find_query_data('stock_account_info', {"type": "ths_cookie", })
    ths_cookie = list(stock_account_info['cookie'])[0]
    return ths_cookie


@lru_cache(maxsize=None)
def get_em_cookie():
    stock_account_info = mongodb_util.find_query_data('stock_account_info', {"type": "em_cookie", })
    em_cookie = list(stock_account_info['cookie'])[0]
    return em_cookie



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 14
project_path = file_path[0:end]
sys.path.append(project_path)
# 大单同步表
BIG_DEAL_NAME = "ths_big_deal_fund"
# 大单选择表
BIG_DEAL_CHOOSE_NAME = "big_deal_fund_choose"
# 实时行情表 临时数据
REAL_TIME_QUOTES_NOW = 'realtime_quotes_now'
# 当前实时涨停表
TODAY_ZT_POOL = 'today_zt_pool'
# 集合竞价表
CALL_AUCTION_DB_NAME = 'call_auction_signal'
# 实时竞价表
CALL_AUCTION_DB_NAME_REAL_TIME = 'call_auction_signal_realtime'
# 涨停打板表
NOW_TIME_ZT_DA_BAN = 'now_time_zt_da_ban'
# 开盘啦精选指数表
KPL_BEST_CHOOSE_INDEX = 'kpl_best_choose_index'
# 开盘啦详细组成
KPL_BEST_CHOOSE_INDEX_DETAIL = "kpl_best_choose_index_detail"

# 同花顺概念表
THS_CONCEPT_LIST = "ths_concept_list"

# 同花顺概念详情表
THS_STOCK_CONCEPT_DETAIL = "ths_stock_concept_detail"

# 同花顺概念详情表 app端
THS_STOCK_CONCEPT_DETAIL_APP = "ths_stock_concept_detail_app"

# 今日排除买入股票
TODAY_EXCLUDE_STOCK = "today_exclude_stocks"
# 今日买入股票
BUY_STOCK_NAME = 'trade_stocks'

#  公司信息表
COMPANY_INFO = 'company_info'
#  公司信息历史表
COMPANY_INFO_HIS = 'company_info_his'

# TODAY_NEW_CONCEPT_LIST
TODAY_NEW_CONCEPT_LIST = 'today_new_concept_list'

# 开票啦历史数据
KPL_BEST_CHOOSE_HIS = 'kpl_best_choose_his'

# 开票啦每日数据
KPL_BEST_CHOOSE_DAILY = 'kpl_best_choose_daily'

# 当前持仓股票
POSITION_STOCK = 'position_stock'

# 个股黑名单
SELF_BLACK_STOCK = 'self_black_stock'
# 自选板块
SELF_CHOOSE_PLATE = 'self_choose_plate'
# 自选个股
SELF_CHOOSE_STOCK = 'self_choose_stock'

# 利润表
EM_STOCK_PROFIT = 'em_stock_profit'

# 资产负债表
EM_STOCK_ASSET_LIABILITY = 'em_stock_asset_liability'

# 退市股票列表
DE_LIST_STOCK = 'de_list_stock'

# 当前涨停列表
STOCK_ZT_POOL = 'stock_zt_pool'

# ths问财涨停股票池
THS_ZT_POOL = 'ths_zt_pool'

# 五板以上的历史高标
STOCK_ZT_POOL_FIVE = 'stock_zt_pool_five'

# 香港公司信息
COMPANY_INFO_HK = 'company_info_hk'

# k线前复权
STOCK_QFQ_DAILY = 'stock_qfq_daily'

# 最近高涨股票
RECENT_HOT_STOCKS = 'recent_hot_stocks'

# 互动提问
STOCK_INTERACTIVE_QUESTION = 'stock_interactive_question'

# 上交所 互动ID映射代码

SSE_INFO_UID = 'sse_info_uid'

# kcx 高涨幅>9.5 当天开盘数据
KCX_HIGH_CHG_OPEN_DATA = 'realtime_quotes_now_zt_new_kc_open'

# 涨停股票(chg>=9.57)实时行情数据
ZT_STOCK_REAL_TIME_QUOTES = "realtime_quotes_now_zt_new"

# 高涨幅和涨停表
STOCK_HIGH_CHG_POOL = 'stock_high_chg_pool'

# 股票账户信息
STOCK_ACCOUNT_INFO = 'stock_account_info'

# 可转债信息
KZZ_DEBT_INFO = 'kzz_debt_info'
# 交易配置信息
TRADE_CONFIG_INFO = 'trade_config_info'

# 公司备注信息
COMPANY_REMARK_INFO = 'company_remark_info'

#  打板待选
DA_BAN_SELF_CHOOSE = 'da_ban_self_choose'
#  打板排除
DA_BAN_SELF_EXCLUDE = 'da_ban_self_exclude'

#  港股公司行业列表
HK_COMPANY_INDUSTRY = 'hk_company_industry'

#  公司控股信息 子孙公司 联营公司
COMPANY_HOLDING_INFO = 'company_holding_info'

#  行业和概念自己的备注
INDUSTRY_CONCEPT_REMARK = 'industry_concept_remark'

#  ths行业对应的股票的备注
INDUSTRY_CONCEPT_SYMBOL_REMARK = 'industry_symbol_remark'

# 复盘日记
FU_PAN_NOTE = 'fu_pan_note'
